@@ -7,7 +7,7 @@ package Dist::Zilla::PluginBundle::Author::KENTNL;
 
 # ABSTRACT: BeLike::KENTNL when you build your distributions.
 
-our $VERSION = '2.020005';
+our $VERSION = '2.021000';
 
 our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
@@ -589,6 +589,8 @@ sub configure {
   $self->_configure_bundle_develop_suggests();
   $self->_configure_bundle_develop_requires();
 
+  $self->add_plugin( 'Prereqs::AuthorDeps' => {} );
+
   $self->add_plugin( 'MinimumPerl' => {} );
   $self->add_plugin(
     'Authority' => {
@@ -611,7 +613,8 @@ sub configure {
   $self->add_plugin( 'Git::Check' => { filename => 'Changes' } );
   $self->add_named_plugin( 'commit_dirty_files' => 'Git::Commit' => {} );
   $self->add_named_plugin( 'tag_master', => 'Git::Tag' => { tag_format => '%v-source' } );
-  $self->add_plugin( 'Git::NextRelease' => { time_zone => 'UTC', format => q[%v %{yyyy-MM-dd'T'HH:mm:ss}dZ] } );
+  $self->add_plugin(
+    'Git::NextRelease' => { ':version' => '0.004000', time_zone => 'UTC', format => q[%v %{yyyy-MM-dd'T'HH:mm:ss}dZ %h] } );
   if ( $self->bumpversions ) {
     $self->add_plugin( 'BumpVersionAfterRelease' => {} );
   }
@@ -670,7 +673,7 @@ Dist::Zilla::PluginBundle::Author::KENTNL - BeLike::KENTNL when you build your d
 
 =head1 VERSION
 
-version 2.020005
+version 2.021000
 
 =head1 SYNOPSIS
 
